from ._surface import Surface
from ._stream import Stream
from ._spaceframe import Spaceframe
from ._slices import Slices
from plotly.graph_objs.isosurface import slices
from ._lightposition import Lightposition
from ._lighting import Lighting
from ._hoverlabel import Hoverlabel
from plotly.graph_objs.isosurface import hoverlabel
from ._contour import Contour
from ._colorbar import ColorBar
from plotly.graph_objs.isosurface import colorbar
from ._caps import Caps
from plotly.graph_objs.isosurface import caps
